==> nextcloud-desktop_3.1.1.orig.tar.gz: desktop-3.1.1/CONTRIBUTING.md <==
## Submitting Desktop Client issues

If you have questions about how to use the Nextcloud Desktop Client, please
visit our [support site][support] or our [forum][forum].
We are also available on [IRC][irc].

### Bug Reporting Guidelines
* __Important__: Report the issue using our [template][template], it includes all the
  information we need to track down the issue.  
* __SECURITY__: Report any potential security bug by following our [security policy](https://nextcloud.com/security/) instead of filing an issue in our bug tracker
* This repository is *only* for issues within the Nextcloud desktop client. 
  Issues in other components should be reported in their own repositores: 
  - [Nextcloud server](https://github.com/nextcloud/server/issues)
  - [Android client](https://github.com/nextcloud/android/issues)
  - [iOS client](https://github.com/nextcloud/ios/issues)
* Search the existing issues first, it's likely that your issue was already
  reported.

If your issue appears to be a bug, and hasn't been reported, open a new issue.

Help us to maximize the effort we can spend fixing issues and adding new
features, by not reporting duplicate issues.

[template]: https://raw.githubusercontent.com/nextcloud/desktop/master/.github/issue_template.md
[support]: https://nextcloud.com/support/
[forum]: https://help.nextcloud.com/categories
[irc]: https://webchat.freenode.net/?channels=nextcloud

## Contributing to Source Code

Thanks for wanting to contribute source code to Nextcloud. That's great!

You do not need to sign a Contributor Agreement, but we ask that you follow our 
[Code of Conduct](https://nextcloud.com/code-of-conduct/).

Please read the [Contribution Guide](https://nextcloud.com/contribute/) to get 
started.

## Translations
Please submit translations via [Transifex](https://www.transifex.com/nextcloud/nextcloud/).

==> nextcloud-desktop_3.16.6.orig.tar.gz: desktop-3.16.6/CONTRIBUTING.md <==
## Submitting Desktop Client issues

If you have questions about how to use the Nextcloud Desktop Client, please
visit our [support site][support] or our [forum][forum].
We are also available on [IRC][irc].

### Bug Reporting Guidelines
* __Important__: Report the issue using our [template][template], it includes all the
  information we need to track down the issue.  
* __SECURITY__: Report any potential security bug by following our [security policy](https://nextcloud.com/security/) instead of filing an issue in our bug tracker
* This repository is *only* for issues within the Nextcloud desktop client. 
  Issues in other components should be reported in their own repositores: 
  - [Nextcloud server](https://github.com/nextcloud/server/issues)
  - [Android client](https://github.com/nextcloud/android/issues)
  - [iOS client](https://github.com/nextcloud/ios/issues)
* Search the existing issues first, it's likely that your issue was already
  reported.

If your issue appears to be a bug, and hasn't been reported, open a new issue.

Help us to maximize the effort we can spend fixing issues and adding new
features, by not reporting duplicate issues.

[template]: https://raw.githubusercontent.com/nextcloud/desktop/master/.github/issue_template.md
[support]: https://nextcloud.com/support/
[forum]: https://help.nextcloud.com/categories
[irc]: https://webchat.freenode.net/?channels=nextcloud

## Contributing to Source Code

Thanks for wanting to contribute source code to Nextcloud. That's great!

You do not need to sign a Contributor Agreement, but we ask that you follow our 
[Code of Conduct](https://nextcloud.com/code-of-conduct/).

Please read the [Contribution Guide](https://nextcloud.com/contribute/) to get 
started and follow the [Coding Style](https://github.com/nextcloud/desktop/wiki/Coding-Style)
when writing new code.

## Translations
Please submit translations via [Transifex](https://www.transifex.com/nextcloud/nextcloud/).
